@@ -1,5 +1,5 @@
 /*
-   Copyright (C) 2013-2016 Montel Laurent <montel@kde.org>
+   Copyright (C) 2013-2017 Montel Laurent <montel@kde.org>
 
    This program is free software; you can redistribute it and/or
    modify it under the terms of the GNU General Public
@@ -44,7 +44,7 @@ public:
         PutInOutbox = 3
     };
 
-    explicit SendLaterDialog(SendLater::SendLaterInfo *info, QWidget *parent = Q_NULLPTR);
+    explicit SendLaterDialog(SendLater::SendLaterInfo *info, QWidget *parent = nullptr);
     ~SendLaterDialog();
 
     SendLater::SendLaterInfo *info();
